//Добавление данных
function [Datas,..//Данные после добавления данных
          DatasHeaders..//Заголовки данных после добавления
          ]=AddDatas(Datas,..//Данные (исходные, к которым добавляем данные)
                     AddingDatas,..//Добавляем данные
                     DatasHeaders,..//Заголовки данных, к которым добавляем данные
                     AddingDatasHeaders,..//Заголовки добавляемых данных
                     Concating,..//Направление конкатенации ('r' - новые ряды, 'с' - новые колонки)
                     Replacing..//Замена значений величины новыми (в случае пересечения столбцов)
                     )
    //Проверяем входные данные
    [nOut,nArg] = argn();//Число аргументов
    if nArg < 2 then
        error('Function AddDatas takes 2, 3, 4, 5 or 6 arguments');
    end
    switch nArg
    case 2 then
        DatasHeaders = [];
        AddingDatasHeaders = [];
        Concating = 'r';
        Replacing = %f;
    case 3 then
        if type(DatasHeaders) == 1 then
            AddingDatasHeaders = DatasHeaders;
            Concating = 'r';
        else
            Concating = DatasHeaders;
            AddingDatasHeaders = [];
        end
        DatasHeaders = [];
        Replacing = %f;
    case 4 then
        if type(DatasHeaders) == 1 then
            if isempty(DatasHeaders) then
                if type(AddingDatasHeaders) ~= 1 then
                    Concating = AddingDatasHeaders;
                    AddingDatasHeaders = [];
                else
                    Concating = 'r';
                end
            else
                Concating = AddingDatasHeaders;
                AddingDatasHeaders = DatasHeaders;
                DatasHeaders = [];
            end
        else
            Concating = 'r';
        end
        Replacing = %f;
    case 5 then
        if type(Concating) == 4 then
            Replacing = Concating;
            if type(DatasHeaders) == 1 then
                Concating = AddingDatasHeaders;
                AddingDatasHeaders = DatasHeaders;
                DatasHeaders = [];
            else
                Concating = 'r';
            end
        else
            Replacing = %f;
        end
    end
    if isempty(Datas) then
        error('The argument Datas of function AddDatas must not be empty');
    end
    if type(Datas) ~= 1 then
        error('The argument Datas of function AddDatas must be matrix of real');
    end
    if isempty(AddingDatas) then
        error('The argument AddingDatas of function AddDatas must not be empty');
    end
    if type(AddingDatas) ~= 1 then
        error('The argument AddingDatas of function AddDatas must be matrix of real');
    end
    if isempty(DatasHeaders) then
        if (size(AddingDatasHeaders)(1) > 1) ||..
           (type(AddingDatasHeaders) ~= 1) then
            error('The argument AddingDatasHeader of function AddDatas must be matrix 1xM of integer');
        end
    else
        if (size(DatasHeaders)(1) ~= 1) ||..
           (type(DatasHeaders) ~= 10) then
            error('The argument DatasHeader of function AddDatas must be matrix 1xM of string');
        end
        if (size(AddingDatasHeaders)(1) ~= 1) ||..
           (type(AddingDatasHeaders) ~= 10) then
            error('The argument AddingDatasHeader of function AddDatas must be matrix 1xM of string');
        end
    end
    if (type(Concating) ~= 10) || (size(Concating,'*') ~= 1) then
        error('The argument Concating of function AddDatas must be string scalar');
    end
    if type(Replacing) ~= 4 then
        error('The argument Replacing of function AddDatas must be boolean scalar')
    end
    
    //Добавляем данные
    switch Concating
    case 'r' then
        //Выдедяем непосредственно добавляемые данные
        if type(AddingDatasHeaders) == 1 then
            if isempty(AddingDatasHeaders) then
                addingDatas = AddingDatas;
            else
                addingDatas = AddingDatas(:,AddingDatasHeaders);
            end
        else
            addingDatas = SelectionDatas(AddingDatasHeaders,..//Заголовок таблицы данных (еще не разделенных)
                                         DatasHeaders,..//Заголовок выделенных данных
                                         AddingDatas..//Данные (отдельно от заголовка, не разделенные)
                                         );
        end
        
        //Добавляем данные
        Datas = [Datas;addingDatas];
    case 'c' then
        nAddingDatas = size(AddingDatas)(1);
        nDatas = size(Datas)(1);
        if nAddingDatas == 1 then
            AddingDatas = repmat(AddingDatas',[1,nDatas])';
        elseif nDatas == 1 then
            Datas = repmat(Datas',[1,nAddingDatas])';
        end
        if isempty(DatasHeaders) then
            if isempty(AddingDatasHeaders) then
                Datas = [Datas,AddingDatas];
            else
                Datas = [Datas,AddingDatas(:,AddingDatasHeaders)];
            end
        else
            [addingDatasHeaders,..
             addingDatasHeadersInd] = setdiff(AddingDatasHeaders,..
                                              DatasHeaders);//Получаем заголовки добавляемых колонок
            addingDatas = AddingDatas(:,addingDatasHeadersInd);//Выделяем добавляемые столбцы
            if Replacing then//Обновляем данные при необходимости
                [a,replacingInd] = members(AddingDatasHeaders,..
                                           DatasHeaders); clear a;
                _replacingInd = replacingInd(replacingInd > 0);
                Datas(:,_replacingInd) = AddingDatas(:,replacingInd > 0);
            end
            Datas = [Datas,addingDatas];
            DatasHeaders = [DatasHeaders,addingDatasHeaders];
        end
    else
        error('The values of argument Concating of function AddDatas must be ""r"" or ""c""');
    end
endfunction
