//Расчет результатов
function [сoutputDatasErr,..//Абсолютные погрешности выходных данных
          сoutputDatas,..//Рассчитанные выходные данные
          outputDatasHeaders,..//Заголовки рассчитанных выходных данных
          outputDatas,..//Экспериментальные выходные данные (выделенные)
          сoutputDatasErrMean,..//Среднее значение погрешности рассчитанных выходных данных
          сoutputDatasErrMax..//Максимальное значение погрешности рассчитанных выходных данных
          ]=CountRezultsErr(inputDatas,..//Входные данные
                            outputDatas,..//Выходные данные
                            inputDatasHeaders,..//Заголовки входных данных
                            outputDatasHeaders,..//Заголовки выходных данных
                            Functions,..//Функции
                            argumentsNames,..//Имена (индексы) аргументов
                            rezultsNames,..//Имена (индексы) результатов
                            isVectorized..//Векторизованы ли функции
                            )
    //Проверяем аргументы
    [nOut,nArg] = argn();//Число аргументов
    if nArg < 5 then
        error('Function CountRezultErr takes 5, 6, 7 or 8 arguments');
    end
    switch nArg
    case 5 then
        rezultsNames = Functions;
        argumentsNames = outputDatasHeaders;
        Functions = inputDatasHeaders;
        outputDatasHeaders = [];
        inputDatasHeaders = [];
        isVectorized = repmat(%t,[1,size(Functions,'*')]);
    case 6 then
        if type(argumentsNames) == 4 then
            isVectorized = argumentsNames;
            rezultsNames = Functions;
            argumentsNames = outputDatasHeaders;
            Functions = inputDatasHeaders;
            outputDatasHeaders = [];
            inputDatasHeaders = [];
        else
            rezultsNames = argumentsNames;
            argumentsNames = Functions;
            Functions = outputDatasHeaders;
            outputDatasHeaders = [];
            isVectorized = repmat(%t,[1,size(Functions,'*')]);
        end
    case 7 then
        if type(rezultsNames) == 4 then
            isVectorized = rezultsNames;
            rezultsNames = argumentsNames;
            argumentsNames = Functions;
            Functions = outputDatasHeaders;
            outputDatasHeaders = [];
        else
            isVectorized = repmat(%t,[1,size(Functions,'*')]);
        end
    end
    if isempty(outputDatas) || (type(outputDatas) ~= 1) then
        error('The outputDatas argument of function CountRezultsErr must be matrix of real');
    end
    
    //Определяем выходные значения
    [сoutputDatas,..
     сoutputDatasHeaders] = CountRezults(inputDatas,..//Входные данные
                                         inputDatasHeaders,..//Заголовки входных данных
                                         Functions,..//Функции
                                         argumentsNames,..//Имена (индексы) аргументов
                                         rezultsNames,..//Имена (индексы) результатов
                                         isVectorized..//Векторизованы ли функции
                                         );
    
    //Выделяем экспериментальные данные
    if ~isempty(сoutputDatasHeaders) then
        if (~isempty(outputDatasHeaders)) ||..
           isempty(outputDatasHeaders) && (type(сoutputDatasHeaders) == 1) then
            [outputDatas,..
             outputDatasHeaders] = SelectionDatas(outputDatasHeaders,..//Заголовок таблицы данных (еще не разделенных)
                                                  сoutputDatasHeaders,..//Заголовок выделенных данных
                                                  outputDatas..//Данные (отдельно от заголовка, не разделенные)
                                                  );
         elseif nOut >= 3 then
            outputDatasHeaders = сoutputDatasHeaders;
         end
    end
                                
    //Определяем абсолютные погрешности
    сoutputDatasErr = abs(сoutputDatas - outputDatas);
    
    //Рассчитвааем среднее и максимальное значения абсолютной погрешности
    if nOut >= 5 then
        сoutputDatasErrMean = mean(сoutputDatasErr,'r');
    end
    if nOut >= 6 then
        сoutputDatasErrMax = max(сoutputDatasErr,'r');
    end
endfunction
